%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% @Brief: Solves Kepler's equation M = E-e*sin(E)
% 
% Computation Uses Newton's Method. More Information :
% https://en.wikipedia.org/wiki/Kepler%27s_equation
% Under "Numerical approximation of inverse problem"
% 
%
% https://www.iriscores.com
% Author: Vojtech Ters 2016/2022
% vojta.ters@iriscores.com
%
% M           ... Mean Anomaly
% e           ... Eccentricity
% eps         ... Precision
% Output [E]  ... Eccentric Anomaly E [rad].
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function E = KeplerSolve(M,e,eps)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% In Case there are Multiple Satellites %
N = length(M);
E = zeros(1,N);


for i = 1:N
    En  = M(i);
	  Ens = En - (En-e*sin(En)- M(i))/(1 - e*cos(En));

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Check for Convergence given the Required Tolerance %
	  while ( abs(Ens-En) > eps )
		  En = Ens;
		  Ens = En - (En - e*sin(En) - M(i))/(1 - e*cos(En));
	  end
	  E(i) = Ens; 
end

end